@@ -23,10 +23,9 @@ import uuid
 
 from bleak import BleakClient
 from bleak.backends.characteristic import BleakGATTCharacteristic
-from bleak.exc import BleakError
 
 from aiohomekit.controller.ble.key import DecryptionKey, EncryptionKey
-from aiohomekit.exceptions import AccessoryDisconnectedError, EncryptionError
+from aiohomekit.exceptions import EncryptionError
 from aiohomekit.model.services import ServicesTypes
 from aiohomekit.pdu import (
     OpCode,
@@ -37,7 +36,8 @@ from aiohomekit.pdu import (
 )
 from aiohomekit.protocol.tlv import TLV
 
-from .const import HAP_MIN_REQUIRED_MTU, AdditionalParameterTypes
+from .bleak import BLEAK_EXCEPTIONS, AIOHomeKitBleakClient
+from .const import AdditionalParameterTypes
 from .structs import BleRequest
 
 logger = logging.getLogger(__name__)
@@ -61,8 +61,8 @@ def retry_bluetooth_connection_error(attempts: int = DEFAULT_ATTEMPTS) -> WrapFu
             for attempt in range(attempts):
                 try:
                     return await func(*args, **kwargs)
-                except (AccessoryDisconnectedError, BleakError):
-                    if attempt == 1:
+                except BLEAK_EXCEPTIONS:
+                    if attempt == attempts - 1:
                         raise
                     logger.debug(
                         "Bleak error calling %s, retrying...", func, exc_info=True
@@ -74,7 +74,7 @@ def retry_bluetooth_connection_error(attempts: int = DEFAULT_ATTEMPTS) -> WrapFu
 
 
 def get_characteristic(
-    client: BleakClient, service_type: str, characteristic_type: str
+    client: AIOHomeKitBleakClient, service_type: str, characteristic_type: str
 ) -> BleakGATTCharacteristic:
     service = client.services.get_service(service_type)
     char = service.get_characteristic(characteristic_type)
@@ -82,7 +82,7 @@ def get_characteristic(
 
 
 async def get_characteristic_iid(
-    client: BleakClient, char: BleakGATTCharacteristic
+    client: AIOHomeKitBleakClient, char: BleakGATTCharacteristic
 ) -> int:
     iid_handle = char.get_descriptor(uuid.UUID("DC46F0FE-81D2-4616-B5D9-6ABDD796939A"))
     value = bytes(await client.read_gatt_descriptor(iid_handle.handle))
@@ -90,7 +90,7 @@ async def get_characteristic_iid(
 
 
 async def ble_request(
-    client: BleakClient,
+    client: AIOHomeKitBleakClient,
     encryption_key: EncryptionKey | None,
     decryption_key: DecryptionKey | None,
     opcode: OpCode,
@@ -104,7 +104,7 @@ async def ble_request(
     # https://github.com/jlusiardi/homekit_python/issues/211#issuecomment-996751939
     # But we haven't confirmed that this isn't already taken into account
 
-    fragment_size = max(HAP_MIN_REQUIRED_MTU, client.mtu_size) - 3
+    fragment_size = client.mtu_size - 3
     if encryption_key:
         # Secure session means an extra 16 bytes of overhead
         fragment_size -= 16
@@ -121,7 +121,7 @@ async def ble_request(
         writes.append(data)
 
     for write in writes:
-        await client.write_gatt_char(handle, write)
+        await client.write_gatt_char(handle, write, True)
 
     data = await client.read_gatt_char(handle)
     if decryption_key:
@@ -191,7 +191,7 @@ async def char_read(
 
 
 async def drive_pairing_state_machine(
-    client: BleakClient,
+    client: AIOHomeKitBleakClient,
     characteristic: str,
     state_machine: Any,
 ) -> Any:
