@@ -20,7 +20,6 @@ import asyncio
 from collections.abc import Callable
 import logging
 
-import async_timeout
 from bleak.backends.device import BLEDevice
 
 from aiohomekit.exceptions import AccessoryDisconnectedError, AccessoryNotFoundError
@@ -34,17 +33,15 @@ MAX_TRANSIENT_ERRORS = 9
 # Shorter time outs and more attempts
 # seems to be better for dbus, and corebluetooth
 # is happy either way. Ideally we want everything
-# to finish in ~35s or declare we cannot connect
+# to finish in < 60s or declare we cannot connect
 
 MAX_CONNECT_ATTEMPTS = 5
-BLEAK_TIMEOUT = 6.75
-OVERALL_TIMEOUT = 7
+BLEAK_TIMEOUT = 10
 
 TRANSIENT_ERRORS = {"le-connection-abort-by-local", "br-connection-canceled"}
 
 
 async def establish_connection(
-    client: AIOHomeKitBleakClient | None,
     device: BLEDevice,
     name: str,
     disconnected_callback: Callable[[AIOHomeKitBleakClient], None],
@@ -56,16 +53,8 @@ async def establish_connection(
     transient_errors = 0
     attempt = 0
 
-    if not client or client.address != device.address:
-        # Only replace the client if the address has changed
-        logger.debug(
-            "%s: Creating new client because address changed from %s to %s",
-            name,
-            client.address if client else None,
-            device.address,
-        )
-        client = AIOHomeKitBleakClient(device)
-        client.set_disconnected_callback(disconnected_callback)
+    client = AIOHomeKitBleakClient(device)
+    client.set_disconnected_callback(disconnected_callback)
 
     def _raise_if_needed(name: str, exc: Exception) -> None:
         """Raise if we reach the max attempts."""
@@ -84,10 +73,7 @@ async def establish_connection(
         attempt += 1
         logger.debug("%s: Connecting (attempt: %s)", name, attempt)
         try:
-            async with async_timeout.timeout(OVERALL_TIMEOUT):
-                # Sometimes the timeout does not actually happen so we wrap
-                # it will yet another timeout
-                await client.connect(timeout=BLEAK_TIMEOUT)
+            await client.connect(timeout=BLEAK_TIMEOUT)
         except asyncio.TimeoutError as exc:
             timeouts += 1
             logger.debug("%s: Timed out trying to connect (attempt: %s)", name, attempt)
