@@ -44,9 +44,10 @@ class BleController(AbstractController):
             pairing._async_ble_device_update(device)
 
         if futures := self._ble_futures.get(data.address):
+            discovery = BleDiscovery(self, device, data)
             logger.debug("BLE device for %s found, fulfilling futures", data.address)
             for future in futures:
-                future.set_result(device)
+                future.set_result(discovery)
             futures.clear()
 
         if data.id in self.discoveries:
@@ -60,7 +61,7 @@ class BleController(AbstractController):
             self._scanner = BleakScanner()
             self._scanner.register_detection_callback(self._device_detected)
             await self._scanner.start()
-        except (BleakDBusError, BleakError) as e:
+        except (FileNotFoundError, BleakDBusError, BleakError) as e:
             logger.debug(
                 "Failed to connect to start scanner, HAP-BLE not available: %s", str(e)
             )
@@ -82,16 +83,16 @@ class BleController(AbstractController):
         for device in self.discoveries.values():
             yield device
 
-    async def async_get_ble_device(
+    async def async_get_discovery(
         self, address: str, timeout: int
-    ) -> BLEDevice | None:
-        """Get a BLE device by address."""
+    ) -> BleDiscovery | None:
+        """Get a discovery by address."""
         if discovery := self.discoveries.get(address):
-            logger.debug("BLE device for %s already found", address)
-            return discovery.device
+            logger.debug("Discovery for %s already found", address)
+            return discovery
 
         logger.debug(
-            "BLE device for address %s not found, waiting for advertisement with timeout: %s",
+            "Discovery for address %s not found, waiting for advertisement with timeout: %s",
             address,
             timeout,
         )
@@ -101,7 +102,7 @@ class BleController(AbstractController):
             return await asyncio.wait_for(future, timeout=timeout)
         except asyncio.TimeoutError:
             logger.debug(
-                "Timed out after %s waiting for discovery of BLE device with address %s",
+                "Timed out after %s waiting for discovery with address %s",
                 timeout,
                 address,
             )
@@ -125,9 +126,15 @@ class BleController(AbstractController):
 
         id_ = hkid.lower()
         device: BLEDevice | None = None
+        description: HomeKitAdvertisement | None = None
+
         if discovery := self.discoveries.get(id_):
             device = discovery.device
-        pairing = self.pairings[id_] = BlePairing(self, pairing_data, device=device)
+            description = discovery.description
+
+        pairing = self.pairings[id_] = BlePairing(
+            self, pairing_data, device=device, description=description
+        )
         self.aliases[alias] = pairing
 
         return pairing
